@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <falcon@gnuhealth.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <falcon@gnuhealth.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,82 +19,76 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 ##############################################################################
-from datetime import date
 from trytond.report import Report
 from trytond.pool import Pool
-from trytond.transaction import Transaction
-from dateutil.relativedelta import relativedelta
 
 __all__ = ['ImmunizationStatusReport']
 
+
 class ImmunizationStatusReport(Report):
     __name__ = 'gnuhealth.immunization_status_report'
 
-
     @classmethod
-    def get_context(cls, records, data):
+    def get_context(cls, records, header, data):
         Sched = Pool().get('gnuhealth.immunization_schedule')
         Patient = Pool().get('gnuhealth.patient')
         patient = Patient(data['patient_id'])
-        
-        context = super(ImmunizationStatusReport, cls).get_context(records,
-            data)
-            
+
+        context = super(ImmunizationStatusReport, cls).get_context(
+            records, header, data)
+
         context['patient'] = patient
         sched = Sched(data['immunization_schedule_id'])
-        
+
         context['immunization_schedule'] = sched
 
         immunizations_to_check = \
             cls.get_immunizations_for_age(patient, sched)
-        
+
         immunization_status = \
             cls.verify_status(immunizations_to_check)
-        
+
         context['immunization_status'] = immunization_status
-        
-        return context 
+
+        return context
 
     @classmethod
-    def get_immunizations_for_age(cls,patient,immunization_schedule):
-        
+    def get_immunizations_for_age(cls, patient, immunization_schedule):
+
         immunizations_for_age = []
-        
+
         for vaccine in immunization_schedule.vaccines:
-            
+
             for dose in vaccine.doses:
                 dose_number, dose_age, age_unit = dose.dose_number, \
                     dose.age_dose, dose.age_unit
-                
-                #TODO : For 3.2, use the generic raw_age argument
-                # from compute_age_from_dates
 
-                p_age = [patient.age.split(' ')[0][:-1], 
-                    patient.age.split(' ')[1][:-1], 
-                    patient.age.split(' ')[2][:-1]]                
+                p_age = [patient.age.split(' ')[0][:-1],
+                         patient.age.split(' ')[1][:-1],
+                         patient.age.split(' ')[2][:-1]]
 
-                #Age of the person in years and months
-                pyears,pmonths = int(p_age[0]),int(p_age[1])
+                # Age of the person in years and months
+                pyears, pmonths = int(p_age[0]), int(p_age[1])
 
                 pmonths = (pyears*12)+pmonths
-                
+
                 if ((age_unit == 'months' and pmonths >= dose_age) or
-                    (age_unit == 'years' and pyears >= dose_age)):
-                        immunization_info = {
-                            'patient' : patient,
-                            'vaccine' : vaccine,
-                            'dose' : dose_number,
-                            'dose_age' : dose_age,
-                            'age_unit' : age_unit,
-                            'status' : None}
-                        
-                        # Add to the list of this person immunization check
-                        immunizations_for_age.append(immunization_info)
+                        (age_unit == 'years' and pyears >= dose_age)):
+                    immunization_info = {
+                        'patient': patient,
+                        'vaccine': vaccine,
+                        'dose': dose_number,
+                        'dose_age': dose_age,
+                        'age_unit': age_unit,
+                        'status': None}
+
+                    # Add to the list of this person immunization check
+                    immunizations_for_age.append(immunization_info)
 
         return immunizations_for_age
 
     @classmethod
-    def verify_status(cls,immunizations_to_check):
+    def verify_status(cls, immunizations_to_check):
         Vaccination = Pool().get('gnuhealth.vaccination')
 
         result = []
@@ -105,12 +99,10 @@ class ImmunizationStatusReport(Report):
                 ('dose', '=', immunization['dose']),
                 ('vaccine.name', '=', immunization['vaccine'].vaccine.name),
                 ])
-           
+
             if res:
                 immunization['status'] = 'ok'
-            
-            result.append(immunization)
-        
-        return result
-        
 
+            result.append(immunization)
+
+        return result
