@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -22,11 +21,12 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_ntd_chagas import *
+from . import health_ntd_chagas
+from . import sequences
 
 def register():
     Pool.register(
-        ChagasDUSurvey,
-        GnuHealthSequences,
-        GnuHealthSequenceSetup,
+        health_ntd_chagas.ChagasDUSurvey,
+        sequences.GnuHealthSequences,
+        sequences.ChagasDUSurveySequence,
         module='health_ntd_chagas', type_='model')
