@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -22,11 +21,11 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_socioeconomics import *
+from .  import health_socioeconomics
 
 def register():
     Pool.register(
-        Party,
-        PatientSESAssessment,
-        GnuHealthPatient,
+        health_socioeconomics.Party,
+        health_socioeconomics.PatientSESAssessment,
+        health_socioeconomics.GnuHealthPatient,
         module='health_socioeconomics', type_='model')
