@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <falcon@gnuhealth.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <falcon@gnuhealth.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #    Copyright (C) 2013  Sebastian Marro <smarro@gnusolidario.org>
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -25,8 +25,11 @@ from trytond.wizard import Wizard, StateView, Button, StateTransition
 from trytond.model import ModelView
 from trytond.transaction import Transaction
 from trytond.pool import Pool
+from trytond.i18n import gettext
+from ..exceptions import (StockMoveExists)
+
+__all__ = ['CreateVaccinationStockMoveInit', 'CreateVaccinationStockMove']
 
-__all__ = ['CreateVaccinationStockMoveInit','CreateVaccinationStockMove']
 
 class CreateVaccinationStockMoveInit(ModelView):
     'Create Vaccination Stock Move Init'
@@ -37,12 +40,12 @@ class CreateVaccinationStockMove(Wizard):
     'Create Vaccination Stock Move'
     __name__ = 'gnuhealth.vaccination.stock.move.create'
 
-    start = StateView('gnuhealth.vaccination.stock.move.init',
-            'health_stock.view_create_vaccination_stock_move', [
+    start = StateView(
+        'gnuhealth.vaccination.stock.move.init',
+        'health_stock.view_create_vaccination_stock_move', [
             Button('Cancel', 'end', 'tryton-cancel'),
-            Button('Create Stock Move', 'create_stock_move',
-                'tryton-ok', True),
-            ])
+            Button('Create Stock Move', 'create_stock_move', 'tryton-ok', True)
+        ])
     create_stock_move = StateTransition()
 
     def transition_create_stock_move(self):
@@ -55,10 +58,12 @@ class CreateVaccinationStockMove(Wizard):
         for vaccination in vaccinations:
 
             if vaccination.moves:
-                self.raise_user_error('stock_move_exists')
-                 
+                raise StockMoveExists(
+                    gettext('health_stock.msg_stock_move_exists')
+                    )
+
             lines = []
-            
+
             line_data = {}
             line_data['origin'] = str(vaccination)
             line_data['from_location'] = \
@@ -74,19 +79,10 @@ class CreateVaccinationStockMove(Wizard):
                 vaccination.vaccine.name.default_uom.id
             line_data['state'] = 'draft'
             lines.append(line_data)
-            
+
             moves = StockMove.create(lines)
 
             StockMove.assign(moves)
             StockMove.do(moves)
-            
-            
+
         return 'end'
-
-    @classmethod
-    def __setup__(cls):
-        super(CreateVaccinationStockMove, cls).__setup__()
-        cls._error_messages.update({
-            'stock_move_exists':
-                'Stock moves already exists!.',})
-
